@@ -106,7 +106,7 @@ class AnimatedObject(object):
                                          modifiers      = [])
             self._current_controllers[attribute] = ctrl
 
-        self.mode = APPEND
+        self.mode = REPLACE
 
     def static_object__get(self):
         return self._object
